ValidatingExtractor

Struct ValidatingExtractor 

pub struct ValidatingExtractor<'a> { /* private fields */ }
An Extract implementation that extracts entities and provides TwitterTextParseResults validation data.

Implementations

Source

impl<'a> ValidatingExtractor<'a>

pub fn new(configuration: &Configuration) -> ValidatingExtractor<'_>

Create a new Extractor. ValidatingExtractor::prep_input must be called prior to extract.

pub fn prep_input(&mut self, s: &str) -> String

Initialize the ValidatingExtractor text length data.

pub fn new_with_nfc_input( configuration: &'a Configuration, s: &str, ) -> ValidatingExtractor<'a>

Create a new Extractor from text that is already nfc-normalized. There’s no need to call ValidatingExtractor::prep_input for this text.