parse

Function parse 

pub fn parse(
    text: &str,
    config: &Configuration,
    extract_urls: bool,
) -> TwitterTextParseResults
Produce a TwitterTextParseResults struct from a str. If extract_urls is true, the weighted length will give all URLs the weight supplied in Configuration, regardless of their length.

This function will allocate an NFC-normalized copy of the input string. If the text is already NFC-normalized, ValidatingExtractor::new_with_nfc_input will be more efficient.