pub struct ValidatingExtractor<'a> { /* private fields */ }Expand description
An Extract implementation that extracts entities and provides TwitterTextParseResults validation data.
Implementations
Sourceimpl<'a> ValidatingExtractor<'a>
impl<'a> ValidatingExtractor<'a>
Sourcepub fn new(configuration: &Configuration) -> ValidatingExtractor<'_>
pub fn new(configuration: &Configuration) -> ValidatingExtractor<'_>
Create a new Extractor. ValidatingExtractor::prep_input must be called prior to extract.
Sourcepub fn prep_input(&mut self, s: &str) -> String
pub fn prep_input(&mut self, s: &str) -> String
Initialize the ValidatingExtractor text length data.
Sourcepub fn new_with_nfc_input(
configuration: &'a Configuration,
s: &str,
) -> ValidatingExtractor<'a>
pub fn new_with_nfc_input( configuration: &'a Configuration, s: &str, ) -> ValidatingExtractor<'a>
Create a new Extractor from text that is already nfc-normalized. There’s no need to call ValidatingExtractor::prep_input for this text.